# coding: utf-8
# Date:
# Filename:

from ja_cvu_normalizer.reader import cvuj_reader
import unittest
import os
import sys
import argparse
from logging import Formatter, getLogger, StreamHandler, DEBUG, WARNING, FileHandler

__author__ = ""
__date__ = ""


""" variables """
formatter = Formatter('%(asctime)-15s - %(levelname)-8s - %(message)s')
logger = getLogger(__name__)
logger.setLevel(DEBUG)

# handler1
handler = StreamHandler(sys.stdout)
handler.setFormatter(formatter)

# handler2 (file)
# handler2 = FileHandler("test.log")
# handler2.setLevel(WARNING)
# handler2.setFormatter(formatter)

logger.addHandler(handler)
# logger.addHandler(handler2)


class TestReader (unittest.TestCase):
    @classmethod
    def setUpClass(self):
        pass

    def test_reader_1(self):
        mapping_table = cvuj_reader(
            "ja_cvu_normalizer/resource/ISO-2022-JP.txt")
        self.assertTrue("髙" in mapping_table)



# coding: utf-8
# Date:
# Filename:

from ja_cvu_normalizer.ja_cvu_normalizer import JaCvuNormalizer
from ja_cvu_normalizer.reader import cvuj_reader
import unittest
import sys
from logging import Formatter, getLogger, StreamHandler, DEBUG, WARNING, FileHandler

__author__ = ""
__date__ = ""

""" variables """
formatter = Formatter('%(asctime)-15s - %(levelname)-8s - %(message)s')
logger = getLogger(__name__)
logger.setLevel(DEBUG)

# handler1
handler = StreamHandler(sys.stdout)
handler.setFormatter(formatter)

# handler2 (file)
# handler2 = FileHandler("test.log")
# handler2.setLevel(WARNING)
# handler2.setFormatter(formatter)

logger.addHandler(handler)
# logger.addHandler(handler2)


class TestJpCvuNormalzier (unittest.TestCase):
    @classmethod
    def setUpClass(self):
        self.jp_cvu_normalizer = JaCvuNormalizer()

    def test_normalize_1(self):
        actual = self.jp_cvu_normalizer.normalize("髙")
        expected = "高"
        self.assertEqual(expected, actual)



# coding: utf-8
# Date:
# Filename:

import csv


def decomment(csvfile):
    for row in csvfile:
        raw = row.split("#")[0].strip()
        if raw:
            yield raw


def to_char(unicodes: list):
    return "".join(map(lambda u: chr(int(u, 16)), unicodes))


def cvuj_reader(filepath):
    mapping_table = dict()
    with open(filepath, encoding="utf-8") as f:
        for row in csv.reader(decomment(f), delimiter="\t"):
            mapper = (to_char([row[0]]), to_char(row[1].split(" ")))
            mapping_table[mapper[0]] = mapper[1]

    return mapping_table



from .reader import cvuj_reader
import os

import logging


class JaCvuNormalizer(object):
    def __init__(
        self,
        mapping_table=None,
        mapping_table_path=os.path.join(
            os.path.dirname(__file__), "resource/ISO-2022-JP.txt"
        ),
    ):
        if mapping_table_path:
            self.mapping_table = cvuj_reader(mapping_table_path)

        if mapping_table:
            self.mapping_table = mapping_table

        if self.mapping_table is None:
            logging.warning("mapping_table is not defined.")
            exit(-1)

    def normalize(self, text: str):
        _text = text
        for key in self.mapping_table:
            _text = _text.replace(key, self.mapping_table[key])
        return _text
